@@ -1,5 +1,4 @@
 """Export HTML."""
-from __future__ import unicode_literals
 import webbrowser
 import re
 import time
@@ -10,7 +9,7 @@ import json
 import subprocess
 from .. import data
 from ..localization import _, get_current_domain
-from ... import util
+from .. import util
 from ... import rumcore
 
 
@@ -214,7 +213,7 @@ def open_in_browser(name):
     """Auto open HTML."""
 
     platform = util.platform()
-    if platform == "osx":
+    if platform == "macos":
         web_handler = None
         try:
             launch_services = os.path.expanduser(
@@ -260,7 +259,9 @@ def export(export_html, chain, result_list, result_content_list):
             HTML_HEADER % {
                 "js": data.get_file('sorttable.js'),
                 "css": data.get_file('results.css'),
-                "icon": util.to_ustr(base64.b64encode(data.get_image('glass.png').GetData())),
+                "icon": util.to_ustr(
+                    base64.b64encode(data.get_image('glass.png', tint=data.RGBA(0x333333FF)).GetData())
+                ),
                 "title": title,
                 "lang": get_current_domain()
             }
