@@ -18,9 +18,8 @@ THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABI
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 IN THE SOFTWARE.
 """
-from __future__ import unicode_literals
 import wx
-from ... import util
+from .. import util
 
 
 class AutoCompleteCombo(wx.ComboCtrl):
@@ -42,10 +41,10 @@ class AutoCompleteCombo(wx.ComboCtrl):
         self.update_semaphore = False
         self.choices = None
         self.changed_callback = changed_callback
-        self.UseAltPopupWindow(True)
+        self.UseAltPopupWindow(False)
 
         # Create list control popup
-        self.list = ListCtrlComboPopup(parent, self.GetTextCtrl())
+        self.list = ListCtrlComboPopup(parent, self)
         self.SetPopupControl(self.list)
 
         # Key bindings and events for the object
@@ -63,15 +62,6 @@ class AutoCompleteCombo(wx.ComboCtrl):
         # Add choices
         self.update_choices(choices, load_last)
 
-    def Create(self, parent):
-        """Create list."""
-
-        # Create list control popup
-        self.list = ListCtrlComboPopup(parent, self.GetTextCtrl())
-        self.SetPopupControl(self.list)
-
-        return True
-
     def set_changed_callback(self, callback):
         """Set changed callback."""
 
@@ -147,6 +137,8 @@ class AutoCompleteCombo(wx.ComboCtrl):
             idx = self.list.list.GetItemCount() - 1
             if idx != -1:
                 self.list.select_item(0)
+            else:
+                self.list.set_selected_text('')
         else:
             self.update_semaphore = True
             self.list.set_selected_text(value)
@@ -159,18 +151,16 @@ class AutoCompleteCombo(wx.ComboCtrl):
         self.GetTextCtrl().SetValue(text)
         self.update_semaphore = False
 
-    def pick_item(self):
-        """Set the choice based on the `TextCtrl` value."""
-
-        value = self.GetTextCtrl().GetValue()
-        if value in self.choices:
-            self.list.set_item(self.choices.index(value))
-
     def on_dismiss(self, event):
         """Load a previously selected choice to the `TextCtrl` on dismiss."""
 
         value = self.list.is_value_waiting()
-        if value >= 0:
+        canceled = self.list.is_canceled()
+        self.list.clear_canceled()
+        if canceled:
+            self.list.set_waiting_value(-1)
+            return
+        elif value >= 0:
             self.GetTextCtrl().SetSelection(0, 0)
             self.list.select_item(value)
             self.GetTextCtrl().SetSelection(0, len(self.GetTextCtrl().GetValue()))
@@ -186,12 +176,11 @@ class AutoCompleteCombo(wx.ComboCtrl):
         """
 
         key = event.GetKeyCode()
-        if key == wx.WXK_DOWN:
+        if key in (wx.WXK_DOWN, wx.WXK_UP) and not self.list.popup_shown:
             self.Popup()
-            self.pick_item()
-        elif key == wx.WXK_UP:
-            self.Popup()
-            self.pick_item()
+        elif key in (wx.WXK_ESCAPE, wx.WXK_RETURN) and self.list.popup_shown:
+            # Quirk with Windows: make sure we capture escape key
+            self.list.on_key_down(event)
         event.Skip()
 
     def on_key_down(self, event):
@@ -204,7 +193,7 @@ class AutoCompleteCombo(wx.ComboCtrl):
             else:
                 self.tab_forward()
             return
-        elif key in [wx.WXK_DELETE, wx.WXK_BACK]:
+        elif key in (wx.WXK_DELETE, wx.WXK_BACK):
             self.update_semaphore = True
         event.Skip()
 
@@ -257,10 +246,12 @@ class AutoCompleteCombo(wx.ComboCtrl):
 class ListCtrlComboPopup(wx.ComboPopup):
     """List control combo popup."""
 
-    def __init__(self, parent, txt_ctrl):
+    def __init__(self, parent, combo_ctrl):
         """Initialize the `ListCtrlComboPopup` object."""
 
-        self.txt_ctrl = txt_ctrl
+        self.canceled = False
+        self.txt_ctrl = combo_ctrl.GetTextCtrl()
+        self.combo_ctrl = combo_ctrl
         self.waiting_value = -1
         self.parent = parent
         self.popup_shown = False
@@ -314,6 +305,7 @@ class ListCtrlComboPopup(wx.ComboPopup):
         curitem = self.list.GetFirstSelected()
         if curitem < self.list.GetItemCount() - 1:
             self.list.Select(curitem + 1)
+            self.list.Focus(curitem + 1)
 
     def prev_item(self):
         """Select previous item."""
@@ -321,11 +313,7 @@ class ListCtrlComboPopup(wx.ComboPopup):
         curitem = self.list.GetFirstSelected()
         if curitem > 0 and self.list.GetItemCount() > 0:
             self.list.Select(curitem - 1)
-
-    def set_item(self, idx):
-        """Set item by index."""
-
-        self.list.Select(idx)
+            self.list.Focus(curitem - 1)
 
     def clear(self):
         """Clear choices."""
@@ -364,6 +352,10 @@ class ListCtrlComboPopup(wx.ComboPopup):
             if curitem != -1:
                 self.waiting_value = curitem
             wx.CallAfter(self.Dismiss)
+        elif key == wx.WXK_ESCAPE:
+            if self.popup_shown:
+                self.set_canceled()
+                wx.CallAfter(self.Dismiss)
         elif key == wx.WXK_DOWN:
             if self.popup_shown:
                 self.next_item()
@@ -380,6 +372,21 @@ class ListCtrlComboPopup(wx.ComboPopup):
         self.resize_dropdown()
         event.Skip()
 
+    def set_canceled(self):
+        """Set canceled."""
+
+        self.canceled = True
+
+    def clear_canceled(self):
+        """Clear canceled."""
+
+        self.canceled = False
+
+    def is_canceled(self):
+        """Check if canceled."""
+
+        return self.canceled
+
     # The following methods are those that are overridable from the
     # `ComboPopup` base class.
 
@@ -423,10 +430,23 @@ class ListCtrlComboPopup(wx.ComboPopup):
 
         return wx.ComboPopup.GetAdjustedSize(self, minWidth, 200, maxHeight)
 
+    def pick_item(self):
+        """Set the choice based on the `TextCtrl` value."""
+
+        value = self.txt_ctrl.GetValue()
+        if value in self.combo_ctrl.choices:
+            index = self.combo_ctrl.choices.index(value)
+        else:
+            index = 0
+        if 0 <= index < self.list.GetItemCount():
+            self.list.Select(index)
+            self.list.Focus(index)
+
     def OnPopup(self):
         """Called immediately after the popup is shown."""
         self.popup_shown = True
         wx.ComboPopup.OnPopup(self)
+        self.pick_item()
 
     def OnDismiss(self):
         """Called when popup is dismissed."""
