@@ -18,12 +18,32 @@ class TimePickerCtrl(TimeCtrl):
         ctrl = wx.TextCtrl(parent)
         self._bg = ctrl.GetBackgroundColour().GetRGB()
         bg = rgba.RGBA(0xFF0000FF)
-        bg.blend(rgba.RGBA(ctrl.GetBackgroundColour().Get()), 60)
+        bg.blend(rgba.RGBA(ctrl.GetBackgroundColour().Get()), 50)
         self._error_bg = wx.Colour(*bg.get_rgb()).GetRGB()
         super().__init__(parent, *args, **kwargs)
         font = ctrl.GetFont()
         self.SetFont(wx.Font(font))
         ctrl.Destroy()
+        self.Bind(wx.EVT_SYS_COLOUR_CHANGED, self.on_color_change)
+
+    def on_color_change(self, event):
+        """Handle color change."""
+
+        self.set_error_bg_color()
+
+        if event:
+            event.Skip()
+
+    def set_error_bg_color(self):
+        """Set error background color."""
+
+        ctrl = wx.TextCtrl(self.GetParent())
+        self._bg = ctrl.GetBackgroundColour().GetRGB()
+        bg = rgba.RGBA(0xFF0000FF)
+        bg.blend(rgba.RGBA(ctrl.GetBackgroundColour().Get()), 50)
+        self._invalidBackgroundColour = wx.Colour(*bg.get_rgb())
+        ctrl.Destroy()
+        self.SetParameters()
 
     def SetParameters(self, **kwargs):
         """Force the colors we want."""
