@@ -319,6 +319,7 @@ class RummageArgs:
         self.full_file_path = False
         self.globstar = False
         self.matchbase = False
+        self.minusnegate = True
         self.encoding_options = {}
 
 
@@ -376,6 +377,7 @@ class RummageFrame(gui.RummageFrame):
         self.Bind(wx.EVT_IDLE, self.on_idle)
         self.Bind(wx.EVT_SIZE, self.on_resize)
         self.Bind(EVT_POST_RESIZE, self.on_post_resize)
+        self.Bind(wx.EVT_SYS_COLOUR_CHANGED, self.on_color_change)
 
         # Extend the status bar
         custom_statusbar.extend_sb(self.m_statusbar)
@@ -408,21 +410,7 @@ class RummageFrame(gui.RummageFrame):
         self.m_result_list.set_wait_lock(_LOCK)
         self.m_result_file_list.load_list(True)
         self.m_result_list.load_list(True)
-        for x in range(self.m_grep_notebook.GetPageCount()):
-            page = self.m_grep_notebook.GetPage(x)
-            if util.platform() == "linux":
-                bg = self.m_grep_notebook.GetBackgroundColour()
-            else:
-                bg = page.GetBackgroundColour()
-            if util.platform() == "macos":
-                factor = 94 if data.RGBA(util.to_rgb(bg.GetRGB())).get_luminance() > 127 else 106
-                bg = bg.ChangeLightness(factor)
-            page.SetBackgroundColour(bg)
-            if x == 0:
-                if util.platform() != "linux":
-                    self.m_grep_notebook.SetBackgroundColour(wx.Colour(bg))
-                self.m_options_collapse.SetBackgroundColour(wx.Colour(bg))
-                self.m_limit_collapse.SetBackgroundColour(wx.Colour(bg))
+        self.update_tab_page_colors()
         self.m_grep_notebook.SetSelection(0)
 
         self.refresh_localization()
@@ -440,18 +428,43 @@ class RummageFrame(gui.RummageFrame):
         self.m_searchfor_textbox.SetFocus()
 
         # So this is to fix some platform specific issues.
-        # We will wait until we are sure we are loaded, then
-        # We will fix mac focusing random elements, and we will
-        # process and resize the window to fix Linux tab issues.
+        # We will wait until we are sure we are loaded,
+        # then we will fix Linux tab issues.
         # Linux seems to need the resize to get its control tab
         # order right as we are hiding some items, but doing it
         # now won't work, so we delay it.
-        refocus = util.platform() == 'macos'
-        resize = util.platform() == 'linux'
-        delay = 500 if util.platform() == 'macos' else 100
-        self.call_later = wx.CallLater(delay, functools.partial(self.on_loaded, refocus=refocus, resize=resize))
+        self.call_later = wx.CallLater(100, functools.partial(self.on_loaded, resize=util.platform() == 'linux'))
         self.call_later.Start()
 
+    def on_color_change(self, event):
+        """Update panel colors for tabs."""
+
+        self.update_tab_page_colors()
+
+        if event:
+            event.Skip()
+
+    def update_tab_page_colors(self):
+        """Update panel colors for tabs."""
+
+        for x in range(self.m_grep_notebook.GetPageCount()):
+            page = self.m_grep_notebook.GetPage(x)
+            if util.platform() == "linux":
+                self.m_grep_notebook.SetBackgroundColour(wx.NullColour)
+                bg = self.m_grep_notebook.GetBackgroundColour()
+            else:
+                page.SetBackgroundColour(wx.NullColour)
+                bg = page.GetBackgroundColour()
+            if util.platform() == "macos":
+                factor = util.MAC_LIGHT if data.RGBA(util.to_rgb(bg.GetRGB())).get_luminance() > 127 else util.MAC_DARK
+                bg = bg.ChangeLightness(factor)
+            page.SetBackgroundColour(bg)
+            if x == 0:
+                if util.platform() != "linux":
+                    self.m_grep_notebook.SetBackgroundColour(wx.Colour(bg))
+                self.m_options_collapse.SetBackgroundColour(wx.Colour(bg))
+                self.m_limit_collapse.SetBackgroundColour(wx.Colour(bg))
+
     def localize(self):
         """Translate strings."""
 
@@ -1176,6 +1189,9 @@ class RummageFrame(gui.RummageFrame):
         if args.matchbase:
             flags |= rumcore.MATCHBASE
 
+        if args.minusnegate:
+            flags |= rumcore.MINUSNEGATE
+
         if args.regexfilepattern:
             flags |= rumcore.FILE_REGEX_MATCH
 
@@ -1341,6 +1357,7 @@ class RummageFrame(gui.RummageFrame):
             args.full_file_path = bool(Settings.get_full_file_path())
             args.globstar = bool(Settings.get_globstar())
             args.matchbase = bool(Settings.get_matchbase())
+            args.minusnegate = bool(Settings.get_minusnegate())
 
             args.filepattern = self.m_filematch_textbox.Value
             if self.m_fileregex_checkbox.GetValue():
@@ -1879,15 +1896,11 @@ class RummageFrame(gui.RummageFrame):
         """
         Stupid workarounds on load.
 
-        Focus after loaded (stupid macOS workaround) and select the appropriate entry.
         Resize window after we are sure everything is loaded (stupid Linux workaround) to fix tab order stuff.
         """
 
         self.call_later.Stop()
 
-        if refocus:
-            self.m_searchfor_textbox.SetFocus()
-
         self.Refresh()
 
         if resize:
