@@ -79,19 +79,7 @@ class SettingsDialog(webview.WebViewMixin, gui.SettingsDialog):
 
         self.m_encoding_list.Bind(wx.EVT_LEFT_DCLICK, self.on_dclick)
         self.alert_player = False
-
-        for x in range(self.m_settings_notebook.GetPageCount()):
-            page = self.m_settings_notebook.GetPage(x)
-            if util.platform() == "linux":
-                bg = self.m_settings_notebook.GetBackgroundColour()
-            else:
-                bg = page.GetBackgroundColour()
-            if util.platform() == "macos":
-                factor = 94 if data.RGBA(util.to_rgb(bg.GetRGB())).get_luminance() > 127 else 106
-                bg = bg.ChangeLightness(factor)
-            page.SetBackgroundColour(bg)
-            if x == 0 and util.platform() != "linux":
-                self.m_settings_notebook.SetBackgroundColour(wx.Colour(bg))
+        self.update_tab_page_colors()
 
         self.localize()
 
@@ -99,6 +87,7 @@ class SettingsDialog(webview.WebViewMixin, gui.SettingsDialog):
         self.set_keybindings(
             [(wx.ACCEL_CMD if util.platform() == "macos" else wx.ACCEL_CTRL, ord('A'), self.on_textctrl_selectall)]
         )
+        self.Bind(wx.EVT_SYS_COLOUR_CHANGED, self.on_color_change)
 
         self.history_types = [
             "target",
@@ -138,6 +127,7 @@ class SettingsDialog(webview.WebViewMixin, gui.SettingsDialog):
         self.m_fullfile_checkbox.SetValue(Settings.get_full_file_path())
         self.m_globstar_checkbox.SetValue(Settings.get_globstar())
         self.m_matchbase_checkbox.SetValue(Settings.get_matchbase())
+        self.m_minusnegate_checkbox.SetValue(Settings.get_minusnegate())
         self.m_visual_alert_checkbox.SetValue(Settings.get_notify())
         self.m_audio_alert_checkbox.SetValue(Settings.get_alert())
         self.alert_methods = Settings.get_platform_notify()
@@ -187,6 +177,32 @@ class SettingsDialog(webview.WebViewMixin, gui.SettingsDialog):
         self.call_later = wx.CallLater(100, functools.partial(self.on_loaded, resize=util.platform() == "linux"))
         self.call_later.Start()
 
+    def on_color_change(self, event):
+        """Handle color change event."""
+
+        self.update_tab_page_colors()
+
+        if event:
+            event.Skip()
+
+    def update_tab_page_colors(self):
+        """Update tab page colors."""
+
+        for x in range(self.m_settings_notebook.GetPageCount()):
+            page = self.m_settings_notebook.GetPage(x)
+            if util.platform() == "linux":
+                self.m_settings_notebook.SetBackgroundColour(wx.NullColour)
+                bg = self.m_settings_notebook.GetBackgroundColour()
+            else:
+                page.SetBackgroundColour(wx.NullColour)
+                bg = page.GetBackgroundColour()
+            if util.platform() == "macos":
+                factor = util.MAC_LIGHT if data.RGBA(util.to_rgb(bg.GetRGB())).get_luminance() > 127 else util.MAC_DARK
+                bg = bg.ChangeLightness(factor)
+            page.SetBackgroundColour(bg)
+            if x == 0 and util.platform() != "linux":
+                self.m_settings_notebook.SetBackgroundColour(wx.Colour(bg))
+
     def on_loaded(self, resize=False, **kwargs):
         """
         Stupid workarounds on load.
@@ -247,6 +263,7 @@ class SettingsDialog(webview.WebViewMixin, gui.SettingsDialog):
         self.FULL_FILE = _("Full path file match")
         self.GLOBSTAR = _("Globstar (full path)")
         self.MATCHBASE = _("Match base (full path)")
+        self.MINUSNEGATE = _("Exclude with '-' (instead of '!')")
         self.REGEX_GROUP = _("Regular Expressions")
         self.PATTERN_LIMIT = _("Pattern Limit")
         self.FILE_MATCH_GROUP = _("File/Folder Matching")
@@ -320,6 +337,7 @@ class SettingsDialog(webview.WebViewMixin, gui.SettingsDialog):
         self.m_fullfile_checkbox.SetLabel(self.FULL_FILE)
         self.m_globstar_checkbox.SetLabel(self.GLOBSTAR)
         self.m_matchbase_checkbox.SetLabel(self.MATCHBASE)
+        self.m_minusnegate_checkbox.SetLabel(self.MINUSNEGATE)
         self.m_pattern_limit_label.SetLabel(self.PATTERN_LIMIT)
         self.m_editor_button.SetLabel(self.SAVE)
         self.m_history_clear_button.SetLabel(self.CLEAR)
@@ -651,6 +669,11 @@ class SettingsDialog(webview.WebViewMixin, gui.SettingsDialog):
 
         Settings.set_matchbase(self.m_matchbase_checkbox.GetValue())
 
+    def on_minusnegate_toggle(self, event):
+        """Handle `minusnegate` toggle."""
+
+        Settings.set_minusnegate(self.m_minusnegate_checkbox.GetValue())
+
     def on_alt_row_toggle(self, event):
         """Handle alternative row color option."""
 
