@@ -4,7 +4,6 @@ Notify.
 Copyright (c) 2013 - 2016 Isaac Muse <isaacmuse@gmail.com>
 License: MIT
 """
-from __future__ import unicode_literals
 from __future__ import absolute_import
 import sys
 from .notify_growl import get_growl, enable_growl, growl_enabled, setup_growl, has_growl, growl_destroy
@@ -19,13 +18,13 @@ else:
 if sys.platform.startswith('win'):
     _PLATFORM = "windows"
 elif sys.platform == "darwin":
-    _PLATFORM = "osx"
+    _PLATFORM = "macos"
 else:
     _PLATFORM = "linux"
 
 if _PLATFORM == "windows":
     from .notify_windows import get_notify, alert, setup, windows_icons, destroy
-elif _PLATFORM == "osx":
+elif _PLATFORM == "macos":
     from .notify_osx import get_notify, alert, setup, destroy
 elif _PLATFORM == "linux":
     from .notify_linux import get_notify, alert, setup, destroy
@@ -36,7 +35,7 @@ __all__ = ("info", "warning", "error", "setup_notifications", "enable_growl", "h
 ###################################
 # Fallback Notifications
 ###################################
-class NotifyFallback(object):
+class NotifyFallback:
     """Fallback class."""
 
     def __init__(self, *args, **kwargs):
@@ -95,7 +94,7 @@ def send_notify(title, message, sound, level):
     growl = get_growl()
     if growl_enabled():
         growl(level, title, message, sound, default_notify)
-    elif _PLATFORM in ["osx", "linux"]:
+    elif _PLATFORM in ["macos", "linux"]:
         notify(title, message, sound, default_notify)
     elif _PLATFORM == "windows":
         notify(title, message, sound, windows_icons[level], default_notify)
@@ -112,7 +111,7 @@ def play_alert():
 ###################################
 # Setup Notifications
 ###################################
-def setup_notifications(app_name, img=None, term_notify=(None, None)):
+def setup_notifications(app_name, img=None, **kwargs):
     """Setup notifications for all platforms."""
 
     destroy()
@@ -126,7 +125,7 @@ def setup_notifications(app_name, img=None, term_notify=(None, None)):
     setup(
         app_name,
         img,
-        term_notify if _PLATFORM == "osx" else None
+        **kwargs
     )
 
 
